@@ -15,7 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 
-// $Id: optionsdialog.h,v 1.2 2003/03/17 22:57:48 mueller Exp $
+// $Id: optionsdialog.h 243664 2003-08-19 21:50:01Z gunnar $
 
 #ifndef OPTIONSDIALOG_H
 #define OPTIONSDIALOG_H
@@ -23,7 +23,9 @@
 #include <qobject.h>
 #include "preferencesui.h"
 #include "texttospeechconfigurationwidget.h"
-class KTabCtl;
+class QTabWidget;
+class KCModule;
+class WordCompletionWidget;
 
 /**This class represents a configuration widget for user preferences.
   *@author Gunnar Schmi Dt
@@ -73,9 +75,14 @@ signals:
    void configurationChanged ();
 
 private:
-   KTabCtl *tabCtl;
+   QTabWidget *tabCtl;
    TextToSpeechConfigurationWidget *commandWidget;
    PreferencesWidget *behaviourWidget;
+   KCModule *kttsd;
+   WordCompletionWidget *completionWidget;
+
+   KCModule *loadKttsd ();
+   void unloadKttsd ();
 };
 
 #endif
